@@ -8,17 +8,6 @@ use Data::Dumper;
 use IO::Socket::INET;
 use Net::SSLeay qw/XN_FLAG_RFC2253 ASN1_STRFLGS_ESC_MSB/;
 
-# Sorting keys helps keeping diffs at minimum between dumps.
-#
-# Quotekeys and Trailingcomma were set to match format used to
-# generate t/data/testcert_extended.crt.pem_dump when it was initially
-# imported to version control. They can likely be dropped in a future
-# release.
-$Data::Dumper::Sortkeys = 1;
-$Data::Dumper::Useqq = 1;
-$Data::Dumper::Quotekeys = 0;
-$Data::Dumper::Trailingcomma = 1;
-
 Net::SSLeay::randomize();
 Net::SSLeay::load_error_strings();
 Net::SSLeay::ERR_load_crypto_strings();
@@ -173,9 +162,7 @@ sub get_cert_details {
   $rv->{pubkey_alg} = Net::SSLeay::OBJ_obj2txt(Net::SSLeay::P_X509_get_pubkey_alg($x509));
   $rv->{pubkey_size} = Net::SSLeay::EVP_PKEY_size(Net::SSLeay::X509_get_pubkey($x509));
   $rv->{pubkey_bits} = Net::SSLeay::EVP_PKEY_bits(Net::SSLeay::X509_get_pubkey($x509));
-  if (Net::SSLeay::SSLeay >= 0x1000000f) {
-    $rv->{pubkey_id} = Net::SSLeay::EVP_PKEY_id(Net::SSLeay::X509_get_pubkey($x509));
-  }
+  $rv->{pubkey_id} = Net::SSLeay::EVP_PKEY_id(Net::SSLeay::X509_get_pubkey($x509));
 
   return $rv;
 }
